## 2021.10.8.0 (2021-10-12)

Add star to all non-0.1 versions (#6146)

## 2020.4.0 (2021-09-01)

Add certifi.contents() (#5989)

Added in commit:
https://github.com/certifi/python-certifi/commit/3e585603ff265552c2e137d064ea092d51332602

Available since version 2020.04.05.

